==> stepfunctions-1.60.0-sources.jar: software/amazon/awscdk/services/stepfunctions/FindStateOptions.java <==
package software.amazon.awscdk.services.stepfunctions;

/**
 * Options for finding reachable states.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:13.484Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.stepfunctions.$Module.class, fqn = "@aws-cdk/aws-stepfunctions.FindStateOptions")
@software.amazon.jsii.Jsii.Proxy(FindStateOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface FindStateOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Whether or not to follow error-handling transitions.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getIncludeErrorHandlers() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link FindStateOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link FindStateOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<FindStateOptions> {
        private java.lang.Boolean includeErrorHandlers;

        /**
         * Sets the value of {@link FindStateOptions#getIncludeErrorHandlers}
         * @param includeErrorHandlers Whether or not to follow error-handling transitions.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder includeErrorHandlers(java.lang.Boolean includeErrorHandlers) {
            this.includeErrorHandlers = includeErrorHandlers;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link FindStateOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public FindStateOptions build() {
            return new Jsii$Proxy(includeErrorHandlers);
        }
    }

    /**
     * An implementation for {@link FindStateOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements FindStateOptions {
        private final java.lang.Boolean includeErrorHandlers;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.includeErrorHandlers = this.jsiiGet("includeErrorHandlers", java.lang.Boolean.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.Boolean includeErrorHandlers) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.includeErrorHandlers = includeErrorHandlers;
        }

        @Override
        public java.lang.Boolean getIncludeErrorHandlers() {
            return this.includeErrorHandlers;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getIncludeErrorHandlers() != null) {
                data.set("includeErrorHandlers", om.valueToTree(this.getIncludeErrorHandlers()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-stepfunctions.FindStateOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            FindStateOptions.Jsii$Proxy that = (FindStateOptions.Jsii$Proxy) o;

            return this.includeErrorHandlers != null ? this.includeErrorHandlers.equals(that.includeErrorHandlers) : that.includeErrorHandlers == null;
        }

        @Override
        public int hashCode() {
            int result = this.includeErrorHandlers != null ? this.includeErrorHandlers.hashCode() : 0;
            return result;
        }
    }
}

==> stepfunctions-1.101.0-sources.jar: software/amazon/awscdk/services/stepfunctions/FindStateOptions.java <==
package software.amazon.awscdk.services.stepfunctions;

/**
 * Options for finding reachable states.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-28T11:07:42.243Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.stepfunctions.$Module.class, fqn = "@aws-cdk/aws-stepfunctions.FindStateOptions")
@software.amazon.jsii.Jsii.Proxy(FindStateOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface FindStateOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Whether or not to follow error-handling transitions.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getIncludeErrorHandlers() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link FindStateOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link FindStateOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<FindStateOptions> {
        private java.lang.Boolean includeErrorHandlers;

        /**
         * Sets the value of {@link FindStateOptions#getIncludeErrorHandlers}
         * @param includeErrorHandlers Whether or not to follow error-handling transitions.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder includeErrorHandlers(java.lang.Boolean includeErrorHandlers) {
            this.includeErrorHandlers = includeErrorHandlers;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link FindStateOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public FindStateOptions build() {
            return new Jsii$Proxy(includeErrorHandlers);
        }
    }

    /**
     * An implementation for {@link FindStateOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements FindStateOptions {
        private final java.lang.Boolean includeErrorHandlers;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.includeErrorHandlers = software.amazon.jsii.Kernel.get(this, "includeErrorHandlers", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.Boolean includeErrorHandlers) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.includeErrorHandlers = includeErrorHandlers;
        }

        @Override
        public final java.lang.Boolean getIncludeErrorHandlers() {
            return this.includeErrorHandlers;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getIncludeErrorHandlers() != null) {
                data.set("includeErrorHandlers", om.valueToTree(this.getIncludeErrorHandlers()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-stepfunctions.FindStateOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            FindStateOptions.Jsii$Proxy that = (FindStateOptions.Jsii$Proxy) o;

            return this.includeErrorHandlers != null ? this.includeErrorHandlers.equals(that.includeErrorHandlers) : that.includeErrorHandlers == null;
        }

        @Override
        public final int hashCode() {
            int result = this.includeErrorHandlers != null ? this.includeErrorHandlers.hashCode() : 0;
            return result;
        }
    }
}
